@@ -56,7 +56,7 @@ lazy_static! {
 /// Censor is a flexible profanity filter that can analyze and/or censor arbitrary text.
 ///
 /// You can also make use of `Censor` via traits `CensorStr` and `CensorIter`, which allow inline
-/// checking and purification of `&str` and `Iterator<Item = char>` respectively.
+/// checking and censoring of `&str` and `Iterator<Item = char>` respectively.
 pub struct Censor<I: Iterator<Item = char>> {
     /// Options
     ignore_false_positives: bool,
@@ -145,7 +145,7 @@ impl<'a> Censor<Chars<'a>> {
 }
 
 impl<I: Iterator<Item = char>> Censor<I> {
-    /// Allocates a new purifier for analyzing and/or censoring text.
+    /// Allocates a new `Censor` for analyzing and/or censoring text.
     pub fn new(text: I) -> Self {
         let (buffer, chars) = Self::buffers_from(text);
 
@@ -203,7 +203,7 @@ impl<I: Iterator<Item = char>> Censor<I> {
         )
     }
 
-    /// Resets the purifier with new text. Does not change any configured options.
+    /// Resets the `Censor` with new text. Does not change any configured options.
     /// This avoids reallocation of internal buffers on the heap.
     pub fn reset(&mut self, text: I) {
         let (buffer, chars) = Self::buffers_from(text);
@@ -304,21 +304,7 @@ impl<I: Iterator<Item = char>> Censor<I> {
 
     /// Converts internal weights to a `Type`.
     fn analysis(&self) -> Type {
-        let mut result = 0;
-        for (i, &weight) in self.weights.iter().enumerate() {
-            let severity: u32 = if weight >= 3 {
-                0b100 // severe
-            } else if weight == 2 {
-                0b010 // moderate
-            } else if weight == 1 {
-                0b001 // mild
-            } else {
-                0 // none
-            };
-
-            result |= severity << (i * 3)
-        }
-        Type { bits: result }
+        weights_to_type(&self.weights)
     }
 
     fn ensure_done(&mut self) {
@@ -328,6 +314,24 @@ impl<I: Iterator<Item = char>> Censor<I> {
     }
 }
 
+fn weights_to_type(weights: &[i8; 4]) -> Type {
+    let mut result = 0;
+    for (i, &weight) in weights.iter().enumerate() {
+        let severity: u32 = if weight >= 3 {
+            0b100 // severe
+        } else if weight == 2 {
+            0b010 // moderate
+        } else if weight == 1 {
+            0b001 // mild
+        } else {
+            0 // none
+        };
+
+        result |= severity << (i * 3)
+    }
+    Type { bits: result }
+}
+
 impl<I: Iterator<Item = char>> Iterator for Censor<I> {
     type Item = char;
 
@@ -449,6 +453,7 @@ impl<I: Iterator<Item = char>> Iterator for Censor<I> {
 
             let weights = &mut self.weights;
             let spy = &self.buffer;
+            let censor_threshold = self.censor_threshold;
             let censor_first_character = self.censor_first_character;
             let censor_replacement = self.censor_replacement;
             self.pending_commit.retain(|pending| {
@@ -461,7 +466,13 @@ impl<I: Iterator<Item = char>> Iterator for Censor<I> {
 
                 // Can pre-commit due to lack of false positive matches.
                 if pending.end < safety_end {
-                    pending.commit(weights, spy, censor_first_character, censor_replacement);
+                    pending.commit(
+                        weights,
+                        spy,
+                        censor_threshold,
+                        censor_first_character,
+                        censor_replacement,
+                    );
                     return false;
                 }
 
@@ -492,6 +503,7 @@ impl<I: Iterator<Item = char>> Iterator for Censor<I> {
             pending.commit(
                 &mut self.weights,
                 &self.buffer,
+                self.censor_threshold,
                 self.censor_first_character,
                 self.censor_replacement,
             );
@@ -621,6 +633,9 @@ mod tests {
             .censor();
 
         assert_eq!(censored, "HELLO f### S### WORLD!");
+
+        // Minor mean-ness is not considered inappropriate
+        assert_eq!("fcking coward".censor(), "f***** coward");
     }
 
     #[test]
@@ -644,9 +659,9 @@ mod tests {
         let (_, _) = Censor::new("abcd".chars())
             .with_censor_replacement('?')
             .censor_and_analyze();
-        let mut purifier = Censor::from_str("abcd");
-        let _ = purifier.censor();
-        let _ = purifier.analyze();
+        let mut censor = Censor::from_str("abcd");
+        let _ = censor.censor();
+        let _ = censor.analyze();
         let (_, _) = Censor::from_str("HELLO crap WORLD!").censor_and_analyze();
     }
 
