@@ -1,5 +1,6 @@
 use crate::buffer_proxy_iterator::BufferProxyIterator;
 use crate::radix::Node;
+use crate::{weights_to_type, Type};
 use std::hash::{Hash, Hasher};
 
 #[derive(Clone)]
@@ -35,6 +36,7 @@ impl Match {
         &self,
         weights: &mut [i8; 4],
         spy: &BufferProxyIterator<I>,
+        censor_threshold: Type,
         censor_first_character: bool,
         censor_replacement: char,
     ) {
@@ -46,6 +48,11 @@ impl Match {
             return;
         }
 
+        if weights_to_type(&self.node.weights).isnt(censor_threshold) {
+            // Match isn't severe enough.
+            return;
+        }
+
         // Censor.
         let offset = if censor_first_character { 0 } else { 1 };
         spy.censor(self.start + offset..=self.end, censor_replacement);
